Rmdawn — Rmdawn 0.0.1 documentation

# Rmdawn

Extract YAML, code, and markdown files from an R markdown (Rmd) file.

The `rmdawn` Python package consists of 2 shell commands and functions:

- `rmdawn()`, which concatenates input files to output an R Markdown (Rmd) file.

- `rmdusk()`, which extracts 1) a YAML file, 2) Python or R scripts and 3) Markdown (md) files from Rmd files.

Write reports in R markdown format and use rmdawn to extract code from R markdown code chunks.